@@ -1,5 +1,5 @@
 """Simple configuration management with python"""
-__version__ = "0.1.10"
+__version__ = "0.1.11"
 import re
 import ast
 from os import path
@@ -17,12 +17,12 @@ class ConfigBox(_ConfigBox): # pragma: no cover
 			if isinstance(v, dict):
 				# Box objects must be created in case they are already
 				# in the `converted` box_config set
-				v = self.__class__(v)
+				#v = ConfigBox(v)
 				if k in self and isinstance(self[k], dict):
 					self[k].update(v)
 					continue
-			if isinstance(v, list) and not isinstance(v, self._box_config['box_intact_types']):
-				v = BoxList(v)
+			#if isinstance(v, list) and not isinstance(v, self._box_config['box_intact_types']):
+			#	v = BoxList(v)
 			try:
 				self.__setattr__(k, v)
 			except (AttributeError, TypeError):
@@ -224,7 +224,7 @@ class Config(ConfigBox):
 			cached       = OrderedDict(),
 			profiles     = set(['default'])
 		)
-		kwargs['box_intact_types'] = kwargs.get('box_intact_types', [list])
+		kwargs['box_intact_types'] = kwargs.get('box_intact_types', [list, Config])
 		super(Config, self).__init__(*args, **kwargs)
 
 	def _load(self, *names):
